@@ -10,7 +10,7 @@ __PACKAGE__->config(
     name    => __PACKAGE__,
     session => {
         expires => 3600,
-        dbi_dbh => 'TestAppCDBI::Model::DBIC',
+        dbi_dbh => 'TestAppDBIC::Model::DBIC',
     }
 );
 
